@@ -1,7 +1,9 @@
 import { css } from '@emotion/css';
 import * as React from 'react';
+import type { JSX } from 'react';
 
 import { GrafanaTheme2 } from '@grafana/data';
+import { Trans } from '@grafana/i18n';
 import { Button, FileUpload, TextArea, useStyles2 } from '@grafana/ui';
 
 export type Props = React.ComponentProps<typeof TextArea> & {
@@ -21,7 +23,7 @@ export const TextInputWithReset = ({ isConfigured, onReset, onFileUpload, ...pro
       </div>
       {isConfigured && (
         <Button className={styles.fileUploadButton} variant="primary" size="md" onClick={onReset}>
-          Reset
+          <Trans i18nKey="auth-config.text-input-with-reset.reset">Reset</Trans>
         </Button>
       )}
       {!isConfigured && (
@@ -34,8 +36,8 @@ export const TextInputWithReset = ({ isConfigured, onReset, onFileUpload, ...pro
 const getStyles = (theme: GrafanaTheme2) => {
   return {
     resetButton: css({
-      borderTopLeftRadius: '0px',
-      borderBottomLeftRadius: '0px',
+      borderTopLeftRadius: 'unset',
+      borderBottomLeftRadius: 'unset',
     }),
     fileUploadButton: css({
       marginLeft: theme.spacing(1),
